package config

import (
	"encoding/json"
	"fmt"
	"os"
	"os/user"
	"path/filepath"
)

type Configuration struct {
	User string `json:"author"`
}

var Config Configuration
var configPath string

func LoadConfig() {
	usr, err := user.Current()
	if err != nil {
		fmt.Println("Error getting current user:", err)
		return
	}

	configPath = filepath.Join(usr.HomeDir, ".ds-config")

	file, err := os.Open(configPath)
	if err != nil {
		if os.IsNotExist(err) {
			return
		}
		fmt.Println("Error opening config file:", err)
		return
	}
	defer file.Close()

	decoder := json.NewDecoder(file)
	if err := decoder.Decode(&Config); err != nil {
		fmt.Println("Error decoding config file:", err)
	}
}

func SaveConfig() {
	file, err := os.Create(configPath)
	if err != nil {
		fmt.Println("Error creating config file:", err)
		return
	}
	defer file.Close()

	encoder := json.NewEncoder(file)
	if err := encoder.Encode(&Config); err != nil {
		fmt.Println("Error encoding config file:", err)
	}
}